@@ -30,7 +30,7 @@ from awscli.customizations.s3.filters import create_filter
 from awscli.customizations.s3.s3handler import S3TransferHandlerFactory
 from awscli.customizations.s3.utils import find_bucket_key, AppendFilter, \
     find_dest_path_comp_key, human_readable_size, \
-    RequestParamsMapper, split_s3_bucket_key
+    RequestParamsMapper, split_s3_bucket_key, block_unsupported_resources
 from awscli.customizations.utils import uni_print
 from awscli.customizations.s3.syncstrategy.base import MissingFileSync, \
     SizeAndLastModifiedSync, NeverSync
@@ -158,14 +158,13 @@ GRANTS = {
         'the granted permissions, and can be set to read, readacl, '
         'writeacl, or full.</li><li><code>Grantee_Type</code> - '
         'Specifies how the grantee is to be identified, and can be set '
-        'to uri, emailaddress, or id.</li><li><code>Grantee_ID</code> - '
+        'to uri or id.</li><li><code>Grantee_ID</code> - '
         'Specifies the grantee based on Grantee_Type. The '
         '<code>Grantee_ID</code> value can be one of:<ul><li><b>uri</b> '
         '- The group\'s URI. For more information, see '
         '<a href="http://docs.aws.amazon.com/AmazonS3/latest/dev/'
         'ACLOverview.html#SpecifyingGrantee">'
         'Who Is a Grantee?</a></li>'
-        '<li><b>emailaddress</b> - The account\'s email address.</li>'
         '<li><b>id</b> - The account\'s canonical ID</li></ul>'
         '</li></ul>'
         'For more information on Amazon S3 access control, see '
@@ -421,7 +420,7 @@ REQUEST_PAYER = {
     'name': 'request-payer', 'choices': ['requester'],
     'nargs': '?', 'const': 'requester',
     'help_text': (
-        'Confirms that the requester knows that she or he will be charged '
+        'Confirms that the requester knows that they will be charged '
         'for the request. Bucket owners need not specify this parameter in '
         'their requests. Documentation on downloading objects from requester '
         'pays buckets can be found at '
@@ -642,6 +641,7 @@ class WebsiteCommand(S3Command):
             path = path[5:]
         if path.endswith('/'):
             path = path[:-1]
+        block_unsupported_resources(path)
         return path
 
 
